#!/bin/bash
set -e
set -x


# If user is not root then exit
if [ "$(id -u)" != "0" ]; then
  echo "Must be run with sudo or by root"
  exit 77
fi

if [ "$(id -u ubuntu)" != "1000" ]; then
 echo "ERROR: Read the docs; a proper OrangeBox setup requires the default user to be [ubuntu]" 1>&2
 exit 1
fi

usage()
{
cat << EOF
usage: $0 options

This script to select desired repository and install packages 

OPTIONS:
   -h      Show this message
   -p      Manually enter in ppa's name (as in ppa:/juju/stable)
EOF
}

get_orangebox_number() {
## assume hostname as been set correctly .. will be checked in postinst
OBNum=`hostname | cut -c 10- -`
echo $OBNum
echo "orangebox_number=$OBNum" > /etc/orange-box.conf
}

setup_ssh_keys() {
        # Disable remote password authentication, since our username/password
        # combo is very well known
        if ! grep -qs "^PasswordAuthentication no" /etc/ssh/sshd_config 2>/dev/null; then
                echo "PasswordAuthentication no" >> /etc/ssh/sshd_config
                invoke-rc.d ssh stop || true
                invoke-rc.d ssh start
        fi
        if [ ! -e /home/ubuntu/.ssh/id_rsa ]; then
                su -l ubuntu -c "ssh-keygen -N '' -f /home/ubuntu/.ssh/id_rsa"
        fi

        install -o ubuntu -g ubuntu -m 0600 template/ssh_config ~ubuntu/.ssh/config
}

install_packages (){
    packages=
    while read package; do
        package=${package%%#*}
        packages="$packages $package"
    done < PACKAGES.list
    apt install -y $packages
}

set_up_ppas(){
if [ "$1" = "default" ];then
  printf "Adding Stable ppa's"
  printf "\n"
  add-apt-repository -y ppa:juju/stable
  add-apt-repository -y ppa:maas/stable
fi
if [ "$1" = "jujuexp" ];then
  printf "Adding juju experimental ppa"
  printf "\n"
  add-apt-repository -y ppa:juju/experimental
fi
if [ "$1" = "maasexp" ];then
  printf "Adding maas experimental ppa"
  printf "\n"
  add-apt-repository -y ppa:maas/proposed
fi
if [ "$1" = "ppaset" ];then
  printf "Build system with custom PPAS"
  printf "\n"
  printf "Enter ppa for juju (i.e. ppa:juju/stable):"
    read JUJUPPA
  printf "Enter ppa for maas (i.e. ppa:maas-maintainers/stable):"
    read MAASPPA
    add-apt-repository -y $JUJUPPA 
    add-apt-repository -y $MAASPPA 
fi

apt-get update -y
apt-get upgrade -y
apt-get install run-one -y
install_packages
setup_ssh_keys
sleep 5
reboot
}

if (($# == 0)); then
  set_up_ppas default
fi

while getopts “hp” OPTION
do
     case $OPTION in
         h)
             usage
             exit 1
             ;;
         p)
             set_up_ppas ppaset 
             ;;
         v)
             VERBOSE=1
             ;;
         ?)
             usage
             exit
             ;;
        \?)
             echo "Invalid option: -$OPTARG" >&2
             ;;
     esac
done

