#!/bin/bash

set -aux
# If user is not root then exit
if [ "$(id -u)" != "0" ]; then
  echo "Must be run with sudo or by root"
  exit 77
fi

#Get ob number
ob_number=`hostname | cut -c 10- -`

# Support MAAS 1.8, and 1.9
maas_ver=$(dpkg -l maas | tail -n1 | awk '{print $3}')
if dpkg --compare-versions $maas_ver lt 1.9; then
     . /etc/maas/maas_cluster.conf
else
     MAAS_URL=http://172.27.${ob_number}.1/MAAS
     CLUSTER_UUID=`grep cluster_uuid /etc/maas/clusterd.conf |awk '{print $2}'`
fi

#AMT Password set
AMT_PASSWORD=Password1+

#Set ip's for MAAS configuration
router_ip=172.27.`expr ${ob_number} + 1`.254
static_low=172.27.${ob_number}.50
static_high=172.27.${ob_number}.253
dhcp_low=172.27.`expr ${ob_number} + 1`.1
dhcp_high=172.27.`expr ${ob_number} + 1`.253
br0_broadcast=172.27.`expr ${ob_number} + 1`.255
dns_ip=172.27.`expr ${ob_number} + 1`.254

#Create the MAAS credentials
maas-region-admin createadmin --username admin --email maas-admin@example.com --password="admin"

#set apikey variable
apikey=`maas-region-admin apikey --username admin | tail -n1`

#login to MAAS
maas login admin $MAAS_URL $apikey
#Add ssh key to MAAS
maas admin sshkeys new key="$(cat /home/ubuntu/.ssh/id_rsa.pub)" || true

#Setup MAAS networking
maas admin node-group-interface update ${CLUSTER_UUID} br0 ip_range_low=$dhcp_low ip_range_high=$dhcp_high static_ip_range_low=$static_low static_ip_range_high=$static_high management=2 broadcast_ip=$br0_broadcast router_ip=$router_ip
maas admin network update maas-br0 default_gateway=$dns_ip dns_servers="$router_ip"
cat >/var/www/html/index.html <<EOF
<meta http-equiv="refresh" content="0; url=/MAAS">
EOF

maas admin maas set-config name=upstream_dns value=$dns_ip
maas admin maas set-config name=dnssec_validation value=no
sed -e 's/dnssec-validation  auto;/dnssec-enable no;dnssec-validation no;/g' -i /etc/bind/named.conf.options
pkill -HUP named

#NOTE possibly add code to make sure images are downloading
#Import boot images
maas admin boot-resources import
while [ $(maas admin boot-images read $CLUSTER_UUID | wc -l) -lt 10 ]; do
echo " Waiting for images to download"
   sleep 10
done
sleep 5
maas admin boot-source-selections create 1 os="ubuntu" release="precise" arches="amd64" subarches="*" labels="*" || true
maas admin boot-source-selections create 1 os="ubuntu" release="wily" arches="amd64" subarches="*" labels="*" || true
maas admin boot-resources import

#Add zones to MAAS for NUC's
maas admin zone read zone1 || maas admin zones create name=zone1 description="Physical machines 1-5"
maas admin zone read zone2 || maas admin zones create name=zone2 description="Physical machines 6-10"
