#!/bin/bash

set -aux
# If user is not root then exit
if [ "$(id -u)" != "0" ]; then
  echo "Must be run with sudo or by root"
  exit 77
fi

#Get ob number
ob_number=`hostname | cut -c 10- -`

# Support MAAS 1.8, and 1.9
maas_ver=$(dpkg -l maas | tail -n1 | awk '{print $3}')
if dpkg --compare-versions $maas_ver lt 1.9; then
     . /etc/maas/maas_cluster.conf
else
     MAAS_URL=http://172.27.${ob_number}.1/MAAS
     CLUSTER_UUID=`grep cluster_uuid /etc/maas/clusterd.conf |awk '{print $2}'`
fi

#AMT Password set
AMT_PASSWORD=Password1+

#Set ip's for MAAS configuration
router_ip=172.27.`expr ${ob_number} + 1`.254
static_low=172.27.${ob_number}.50
static_high=172.27.${ob_number}.253
dhcp_low=172.27.`expr ${ob_number} + 1`.1
dhcp_high=172.27.`expr ${ob_number} + 1`.253
br0_broadcast=172.27.`expr ${ob_number} + 1`.255
dns_ip=172.27.`expr ${ob_number} + 1`.254

#set apikey variable
apikey=`maas-region-admin apikey --username admin | tail -n1`

#login to MAAS
maas login admin $MAAS_URL $apikey

#Add nodes to MAAS
for amtnum in {11..20}
do
ping -c 2 172.27.${ob_number}.${amtnum}
#Get mac address for the corresponding amt ip address
mac=`arp -n | grep 172.27.${ob_number}.$amtnum |awk '{print $3}'`
echo "$mac belongs to node${amtnum}ob${ob_number} with ip 172.27.${ob_number}.${amtnum}"
#Get the node number for the name out of the amt ip address
nodenum=`expr ${amtnum} - 10`
if [ ${nodenum} -lt 10 ]; then
     nodenum="0${nodenum}"
fi
echo "The name of the node is node${nodenum}ob${ob_number}"
#Add each node to MAAS and commission it
maas admin nodes new nodegroup=${CLUSTER_UUID} architecture=amd64 power_type=amt mac_addresses=${mac} power_parameters_mac_address=${mac} power_parameters_power_address=172.27.${ob_number}.${amtnum} power_parameters_power_pass=Password1+ hostname=node${nodenum}ob${ob_number}

#Set AMT to work with VNC and Remmina
	wsman put http://intel.com/wbem/wscim/1/ips-schema/1/IPS_KVMRedirectionSettingData -h 172.27.${ob_number}.${amtnum} -P 16992 -u admin -p ${AMT_PASSWORD} -k RFBPassword=Ubuntu1+ > /dev/null 2>&1
	# enable KVM redirection to port 5900
	wsman put http://intel.com/wbem/wscim/1/ips-schema/1/IPS_KVMRedirectionSettingData -h 172.27.${ob_number}.${amtnum} -P 16992 -u admin -p ${AMT_PASSWORD} -k Is5900PortEnabled=true > /dev/null 2>&1
	# disable opt-in policy
	wsman put http://intel.com/wbem/wscim/1/ips-schema/1/IPS_KVMRedirectionSettingData -h 172.27.${ob_number}.${amtnum} -P 16992 -u admin -p ${AMT_PASSWORD} -k OptInPolicy=false > /dev/null 2>&1
	# disable session timeout
	wsman put http://intel.com/wbem/wscim/1/ips-schema/1/IPS_KVMRedirectionSettingData -h 172.27.${ob_number}.${amtnum} -P 16992 -u admin -p ${AMT_PASSWORD} -k SessionTimeout=0 > /dev/null 2>&1
	# enable KVM
	wsman invoke -a RequestStateChange http://schemas.dmtf.org/wbem/wscim/1/cim-schema/2/CIM_KVMRedirectionSAP -h 172.27.${ob_number}.${amtnum} -P 16992 -u admin -p ${AMT_PASSWORD} -k RequestedState=2 > /dev/null 2>&1

#Add tags to MAAS if not already there
maas admin tags new name=physical || true
maas admin tags new name=use-fastpath-installer || true
#Get the system id of each node
system_id=$(maas admin nodes list mac_address=$mac | grep system_id | cut -d'"' -f4)
echo $system_id
#Assign tags to each node
maas admin tag update-nodes "physical" add=$system_id
maas admin tag update-nodes "use-fastpath-installer" add=$system_id
#Determine which zone a node will be in
if [ ${nodenum} -lt 6 ]; then
                zone="zone1"
        else
                zone="zone2"
fi
echo "Node node${nodenum}ob${ob_number} is in $zone"
#Add the nodes to their respective zone
maas admin nodes set-zone zone=$zone nodes=$system_id
maas admin network connect-macs maas-br0 macs=$mac

done
