#!/bin/bash

set -e
set -u

BIOS_PREFIX=MYBDWi5v.86A.
USERNAME=ubuntu
HOSTNAME_REGEX='OrangeBox[0-9][0-9]'

. VARS

ERROR=
log() {
    type=$1
    format=$2
    shift 2
    case $type in
        error)
            printf '\e[1;31mERROR:\e[0m   '
            # shellcheck disable=SC2059
            printf "${format}\n" "$@"
            ERROR=1
        ;;
        warn)
            printf '\e[1;33mWARNING:\e[0m '
            # shellcheck disable=SC2059
            printf "${format}\n" "$@"
        ;;
        info)
            printf '\e[0;32mINFO:\e[0m    '
            # shellcheck disable=SC2059
            printf "${format}\n" "$@"
        ;;
        *)
            echo 'log: unknown type specified.'
            exit 1
        ;;
    esac
}

check_bios_revision() {
    bios_version=$(sudo dmidecode -s bios-version | cut -d' ' -f2)
    bios_revision=${bios_version#$BIOS_PREFIX}
    bios_revision=${bios_revision%%.*}

    if [ "$bios_revision" = "$TESTED_BIOS_REVISION" ]; then
        log info 'You have the tested BIOS revision - %s' "$TESTED_BIOS_REVISION"
    else
        log warn 'The current tested BIOS revision is %s, but you have revision %s' "$TESTED_BIOS_REVISION" "$bios_revision"
    fi
}

check_hostname() {
    if echo "$HOSTNAME" | egrep -q "^${HOSTNAME_REGEX}$"; then
        log info 'hostname is OK - %s' "$HOSTNAME"
    else
        log error 'hostname must meet the regex "%s"' "$HOSTNAME_REGEX"
    fi
}

check_username() {
    if [ "$USER" = "$USERNAME" ]; then
        log info 'username is OK - %s' "$USERNAME"
    else
        log error 'username must be "%s"' "$USERNAME"
    fi
}

# get sudo permission
sudo true

check_bios_revision
check_hostname
check_username

if [ "$ERROR" = 1 ]; then
    exit 1
fi
