#!/bin/bash
#
#   bundle2local
#    Copyright (C) 2014 Canonical Ltd.
#
#    Authors:         Nicolas Thomas <nicolas.thomas@canonical.com>
#  
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, version 3 of the License.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

## TODO start from juju-deployer to do the same but more beautifully .. 
set -ex


bundle2local()
{

[ -d charmstore/trusty ] || mkdir -p charmstore/trusty
[ -d charmstore/precise ] || mkdir -p charmstore/precise
TMPFILE=`mktemp`
CACHEDIRS=`mktemp`
ROOTDIR=$PWD

### this is THE biggest hack deployer know how to match charmstore to specific version reuse that and turn it into local charms. bonus it is super fast
juju-deployer -vbu -c $1 2>&1 | grep "Cache dir" |awk '{print $5}' > $CACHEDIRS

## regex to get serie and charm name.
grep "charm:" $1  | sed -r 's!.*charm\s*.*.*(trusty|precise)\/(.*)!\1:\2!' > $TMPFILE       
#normalise if there is " or ' some bundle don't have them
sed -ie 's|["'\'']||g' $TMPFILE  
while IFS=: read serie charm
do           
    canonicalcharm=`echo $charm | sed -r 's!(.*)-.*[0-9]$!\1!'`
    CHARMDIR=`grep $serie_$charm $CACHEDIRS` 
    [ -d charmstore/$serie/$charm ] || mkdir -p charmstore/$serie/$charm
    cp -rf $CHARMDIR/* charmstore/$serie/$charm/ 
cd $ROOTDIR
done <$TMPFILE
## Now create a -local version of the bundle:
BASEFILE=`basename $1 .yaml`
cat $1 | sed -r 's!(^.*\s)charm:\s*(.*)*(trusty|precise)\/(.*)*"$!\1charm: local:\3/\4!'  > ${BASEFILE}-local.yaml
cat <<EOF
You can now do:
export JUJU_REPOSITORY=$ROOTDIR/charmstore
juju-deployer -c ${BASEFILE}-local.yaml

To use your locally copied charms
If your bundle was already using some local charms you will have to copy them in $ROOTDIR/charmstore
EOF

}

usage()
{
cat << EOF

bundle2local - create a local usable copy of charms and create a local version of the bundle

USAGE: bundle2local mybundle.yaml
    Be sure to have charm-tools installed
    If already downloaded a pull request will be done.
    the charmstore will be local to the directory you run the script in.
EOF
exit 0
}


[ $# -lt 1 ] && usage
[ -f $1 ] || usage
BUNDLE=$1

bundle2local $1

