#!/bin/bash

#
#    01-deploy.sh
#    Copyright (C) 2014 Canonical Ltd.
#
#    Authors: Darryl Weaver <darryl.weaver@canonical.com>
#             Nicolas Thomas <nicolas.thomas@canonical.com>
#  
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, version 3 of the License.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

set -e

juju set-constraints mem=2048
JUJU_TYPE=`cat ${JUJU_HOME:-~/.juju}/environments/$(juju switch).jenv|grep type|awk '{print $2;}'`

export ADMIN_PASS=`cat ${JUJU_HOME:-~/.juju}/environments/$(juju switch).jenv|grep admin-secret|awk '{print $2;}'`
    cat << EOF > cf-bundle.yaml
cloudfoundry:
    series: trusty
    services:
        cloudfoundry:
            charm: local:trusty/cloudfoundry
            num_untis: 1
            constraints: mem=2048
            options:
                admin_secret: $ADMIN_PASS
                placement: ${1:-dense}
                cf_version: latest
EOF

    cat << EOF > cf-bundle-gui.yaml
cloudfoundry:
    series: trusty
    services:
        cloudfoundry:
            charm: "cs:~cf-charmers/trusty/cloudfoundry"
            num_untis: 1
            constraints: mem=2048
            options:
                admin_secret: $ADMIN_PASS
                placement: ${1:-dense}
                cf_version: latest
EOF

export JUJU_REPOSITORY=$PWD
juju-deployer -c cf-bundle.yaml
    

## need to IP or dns of the domain but need to know haproxy IP to do so
API_IP=`juju-pprint |grep haproxy |awk '{ print $3 }' |xargs dig +short`
juju set cloudfoundry  domain=$API_IP.xip.io

echo "Deployment completed"
echo "run:"
echo " source trusty/cloudfoundry/helpers.sh"
echo " cflogin"
echo "    ... in a few minutes"
