#!/bin/bash

# set -ex

echo .
echo "Deploying flight delay demo..."
echo "##########################"
echo -n "Deployment start: "; date +"%T"
echo "##########################"
echo .

for package in jq
do
	if [ $(dpkg-query -W -f='${Status}' $package 2>/dev/null | grep -c "ok installed") -eq 0 ]; then
  		sudo apt-get install $package;
	fi
done

echo "Deploying Juju environment and GUI..."

(juju bootstrap > /dev/null 2>&1) || echo "Already bootstrapped. Moving forward"
juju deploy --to 0 juju-gui > /dev/null 2>&1
juju expose juju-gui

TITLE="Deploying YARN and Compute Nodes..."
echo .
echo $TITLE
echo .

juju deploy --constraints "mem=16G cpu-cores=4 root-disk=128G" hdp-hadoop yarn-master > /dev/null 2>&1
juju deploy --constraints "mem=16G cpu-cores=4 root-disk=128G" hdp-hadoop compute-node > /dev/null 2>&1
juju set-constraints --service compute-node mem=16G cpu-cores=4 root-disk=128G

juju add-relation yarn-master:namenode compute-node:datanode
juju add-relation yarn-master:resourcemanager compute-node:nodemanager 

juju add-unit -n3 compute-node 

ENVIRONMENT=$(juju get-environment | grep "^name:" | cut -f2 -d":" | cut -f2 -d" ")
URL=$(juju api-endpoints | cut -f1 -d":")
IP=$(nslookup $URL | grep Address | grep -v "#" | awk -F " " '{print $2}')
PASS=$(cat ~/.juju/environments/${ENVIRONMENT}.jenv | grep password | cut -f2 -d":" | cut -f2 -d" ")

# This is a race condition potential issue. We lock deployment until the whole deployment is done. 
echo "Waiting for the Hadoop Cluster to deploy completely before moving forward"
sleep 10
while `juju stat | python -c 'import sys, yaml, json; json.dump(yaml.load(sys.stdin), sys.stdout, indent=4)' | jq '.services' | grep "agent-state" | grep -q "pending"`
do 
	sleep 10
done

echo .
echo "Deployment of Hadoop cluster finished."
echo "You can now connect on http://${URL} or http://${IP} and use password ${PASS}"

TITLE="Installing ipython-notebook and pig on YARN Master..."
echo .
echo $TITLE
echo . 
    
TARGET_MACHINE=$(juju stat | python -c 'import sys, yaml, json; json.dump(yaml.load(sys.stdin), sys.stdout, indent=4)' | jq '.services["yarn-master"].units["yarn-master/0"].machine' | tr -d "\"" )
MACHINE=$(juju stat yarn-master/0 --format json | sed -e 's/[{}]/''/g' | awk -v RS=',"' -F: '/^public-address/ {print $2}'| tr -d "\"" | uniq)
echo "We will install ipython-notebook and pig on machine $MACHINE"

juju deploy --to $TARGET_MACHINE cs:~samuel-cozannet/trusty/ipython-notebook ipython-notebook > /dev/null 2>&1
juju expose ipython-notebook

juju deploy --to $TARGET_MACHINE hdp-pig hdp-pig > /dev/null 2>&1
juju add-relation hdp-pig:namenode yarn-master:namenode 
juju add-relation hdp-pig:resourcemanager yarn-master:resourcemanager 
    
MACHINE=$(juju stat ipython-notebook/0 --format json | sed -e 's/[{}]/''/g' | awk -v RS=',"' -F: '/^public-address/ {print $2}'| tr -d "\"" | uniq)
echo "Once the installation finishes you can connect on the notebook at https://${MACHINE}"

TITLE="Installing demo files for ipython-notebook"
echo .
echo $TITLE
echo . 
    
juju deploy cs:~samuel-cozannet/trusty/flight-delay-demo > /dev/null 2>&1
juju add-relation flight-delay-demo ipython-notebook 

echo "Waiting for the flight demo to deploy"
sleep 10
while `juju stat | python -c 'import sys, yaml, json; json.dump(yaml.load(sys.stdin), sys.stdout, indent=4)' | jq '.services' | grep "agent-state" | grep -q "pending"`
do    
        sleep 10
done
echo ""
echo .
echo "Deployment of flight delay demo finished."
echo "##########################"
echo -n "Deployment end:  "; date +"%T"
echo "##########################"
echo "You can now connect on http://${URL} and use password ${PASS}"
echo .
