#!/bin/bash
#
#    orange-box-configure-openstack
#    Copyright (C) 2014 Canonical Ltd.
#
#    Authors: Darryl Weaver <darryl.weaver@canonical.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, version 3 of the License.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

set -ex


echo "This command is run to configure an Orange-Box Multi Region Openstack deployment"

QUANTUM_EXT_NET_GW="10.14.4.1"
QUANTUM_EXT_NET_CIDR="10.14.0.0/16"
QUANTUM_EXT_NET_NAME="ext_net"
QUANTUM_DNS="10.14.4.1"

QUANTUM_FLOAT_RANGE_START="10.14.150.1"
QUANTUM_FLOAT_RANGE_END="10.14.199.254"

QUANTUM_FIXED_NET_CIDR="192.168.14.0/24"
QUANTUM_FIXED_NET_NAME="admin_net1"

keystone=$(juju status keystone | grep public-address | head -1 | awk '{print $2}')

echo "export SERVICE_ENDPOINT=http://$keystone:35357/v2.0/
export SERVICE_TOKEN=admin
export OS_AUTH_URL=http://$keystone:35357/v2.0/
export OS_USERNAME=admin
export OS_PASSWORD=admin
export OS_TENANT_NAME=admin
export OS_REGION_NAME=RegionOne
" > ~/nova-r1.rc

echo "export SERVICE_ENDPOINT=http://$keystone:35357/v2.0/
export SERVICE_TOKEN=admin
export OS_AUTH_URL=http://$keystone:35357/v2.0/
export OS_USERNAME=admin
export OS_PASSWORD=admin
export OS_TENANT_NAME=admin
export OS_REGION_NAME=RegionTwo
" > ~/nova-r2.rc


for i in 1 2
do
source ~/nova-r$i.rc

#Set Network details for region 2
if [ "$i" = "2" ]; then
	QUANTUM_FLOAT_RANGE_START="10.14.200.1"
	QUANTUM_FLOAT_RANGE_END="10.14.249.254"
	QUANTUM_FIXED_NET_CIDR="192.168.15.0/24"
	QUANTUM_FIXED_NET_NAME="admin_net2"
	#configure availability zones for region2
	nova aggregate-create r2-az1 r2-az1
	nova aggregate-create r2-az2 r2-az2
else
	#configure availability zones for region1
	nova aggregate-create r1-az1 r1-az1
        nova aggregate-create r1-az2 r1-az2
fi

#get hosts and allocate to zones
n=0
for host in `nova host-list | grep compute | cut -d' ' -f2`
do
	if [ $n -le 1 ]; then
		AZ="az1"
	else
		AZ="az2"
	fi
	REGION="r$i"
	AGGREGATE="$REGION-$AZ"
	nova aggregate-add-host $AGGREGATE $host
	n=$(($n + 1))
done

# Determine the tenant id for the configured tenant name.
export TENANT_ID="$(keystone tenant-list | grep $OS_TENANT_NAME | awk '{ print $2 }')"

#create ext network with neutron for floating IPs
EXTERNAL_NETWORK_ID=$(neutron net-create ext_net --tenant-id $TENANT_ID -- --router:external=True | grep " id" | awk '{print $4}')
neutron subnet-create ext_net $QUANTUM_EXT_NET_CIDR --name ext_net_subnet --tenant-id $TENANT_ID \
--allocation-pool start=$QUANTUM_FLOAT_RANGE_START,end=$QUANTUM_FLOAT_RANGE_END \
--gateway $QUANTUM_EXT_NET_GW --disable-dhcp --dns_nameservers $QUANTUM_DNS list=true

#Create private network for neutron for tenant VMs
neutron net-create private
SUBNET_ID=$(neutron subnet-create private $QUANTUM_FIXED_NET_CIDR -- --name private_subnet --dns_nameservers list=true $QUANTUM_DNS | grep " id" | awk '{print $4}')

#Create router for external network and private network
ROUTER_ID=$(neutron router-create --tenant-id $TENANT_ID provider-router | grep " id" | awk '{print $4}')
neutron router-interface-add $ROUTER_ID $SUBNET_ID
neutron router-gateway-set $ROUTER_ID $EXTERNAL_NETWORK_ID

#Configure the default security group to allow ICMP and SSH
nova  secgroup-add-rule default icmp -1 -1 0.0.0.0/0
nova  secgroup-add-rule default tcp 22 22 0.0.0.0/0
#for rdp
nova secgroup-add-rule default tcp 3389 3389 0.0.0.0/0

#Upload a default SSH key
nova  keypair-add --pub-key ~/.ssh/id_rsa.pub default

#Remove the m1.tiny as it is too small for Ubuntu.
nova flavor-delete m1.tiny

#Modify quotas for the tenant to allow large deployments
nova quota-update --instances 100 $TENANT_ID
nova quota-update --cores 200 $TENANT_ID
nova quota-update --ram 204800 $TENANT_ID
nova quota-update --security-groups 200 $TENANT_ID

#Upload images to glance
glance add name="Precise x86_64" is_public=true container_format=ovf disk_format=qcow2 <  /srv/data/precise-server-cloudimg-amd64-disk1.img 
glance add name="Trusty x86_64" is_public=true container_format=ovf disk_format=qcow2 <  /srv/data/trusty-server-cloudimg-amd64-disk1.img
glance add name="CentOS 6.4" is_public=true container_format=bare disk_format=qcow2 < /srv/data/centos6.4-x86_64-gold-master.img
glance add name="Cirros 0.3" is_public=true container_format=bare disk_format=qcow2 < /srv/data/cirros-0.3.2-x86_64-disk.img
glance add name="Windows Server 2012" is_public=true container_format=bare disk_format=qcow2 < /srv/data/windows_server_2012_r2_standard_eval_kvm_20140607.qcow2 &

done

exit
