#!/bin/bash
#
set -e

echo "This command is run to configure an Orange-Box Project Calico Openstack deployment"

QUANTUM_EXT_NET_GW="10.15.0.1"
QUANTUM_EXT_NET_CIDR="10.15.0.0/16"
QUANTUM_EXT_NET_NAME="ext_net"
QUANTUM_DNS="10.14.4.1"
QUANTUM_FLOAT_RANGE_START="10.15.0.2"
QUANTUM_FLOAT_RANGE_END="10.15.50.254"
#IPV6=$(grep ipv6 calico.yaml | sed -e 's/.*: //')
#QUANTUM_EXT_NET_V6_CIDR="2001:db8:a41:2::/64"
#QUANTUM_DNS_V6="2a00:1450:4009:80c::200e"

QUANTUM_FIXED_NET_CIDR="192.168.14.0/24"
QUANTUM_FIXED_NET_NAME="admin_net"

keystone=$(juju status keystone | grep public-address | head -1 | awk '{print $2}')
compute_node=$(juju status nova-compute/0 | grep public-address | head -1 | awk '{print $2}')
COMP_IP=$(host $compute_node | awk '{print $4}')

echo "export SERVICE_ENDPOINT=http://$keystone:35357/v2.0/
export SERVICE_TOKEN=admin
export OS_AUTH_URL=http://$keystone:35357/v2.0/
export OS_USERNAME=admin
export OS_PASSWORD=admin
export OS_TENANT_NAME=admin
export OS_REGION_NAME=RegionOne
" > ~/nova.rc

source ~/nova.rc

# Determine the tenant id for the configured tenant name.
export TENANT_ID="$(keystone tenant-list | grep $OS_TENANT_NAME | awk '{ print $2 }')"

if [ "$TENANT_ID" = "" ]; then
	echo "Unable to find tenant ID, keystone auth problem"
	exit
fi

echo "Configuring Openstack Calico Networking"

#create ext network with neutron for external routable IPs
neutron net-show ext_net > /dev/null 2>&1 || neutron net-create ext_net --tenant-id $TENANT_ID
EXTERNAL_NETWORK_ID=$(neutron net-show ext_net | grep " id" | awk '{print $4}')
neutron subnet-show ext_net_subnet > /dev/null 2>&1 || neutron subnet-create ext_net $QUANTUM_EXT_NET_CIDR --name ext_net_subnet --tenant-id $TENANT_ID \
--allocation-pool start=$QUANTUM_FLOAT_RANGE_START,end=$QUANTUM_FLOAT_RANGE_END \
--gateway $QUANTUM_EXT_NET_GW --dns_nameservers $QUANTUM_DNS list=true
#if [ "$IPV6" = "true" ]; then
#	neutron subnet-show ext_net_v6_subnet > /dev/null 2>&1 || neutron subnet-create ext_net $QUANTUM_EXT_NET_V6_CIDR --ip-version 6 --name ext_net_v6_subnet --tenant-id $TENANT_ID \
#	--dns_nameservers $QUANTUM_DNS_V6 list=true
#fi

#Create private network for neutron for unroutable tenant VMs
neutron net-show private > /dev/null 2>&1 || neutron net-create private
neutron subnet-show private_subnet > /dev/null 2>&1 || neutron subnet-create private $QUANTUM_FIXED_NET_CIDR -- --name private_subnet --dns_nameservers list=true $QUANTUM_DNS
SUBNET_ID=$(neutron subnet-show private_subnet | grep " id" | awk '{print $4}')

echo "Adding Openstack Calico Network routes to node0"
sudo ip route del $QUANTUM_EXT_NET_CIDR  || true
sudo ip route del $QUANTUM_FIXED_NET_CIDR || true
sudo ip route add $QUANTUM_EXT_NET_CIDR via $COMP_IP
sudo ip route add $QUANTUM_FIXED_NET_CIDR via $COMP_IP
#if [ "$IPV6" = "true" ]; then
#	sudo ip -6 route del $QUANTUM_EXT_NET_V6_CIDR || true
#	sudo ip -6 route add $QUANTUM_EXT_NET_V6_CIDR via $COMP_IP_V6
#fi


echo "Configuring security groups for access to ICMP, SSH and RDP by default"

#Configure the default security group to allow ICMP and SSH
neutron security-group-rule-list | grep icmp  > /dev/null 2>&1 || neutron security-group-rule-create default --protocol icmp --remote-ip-prefix 0.0.0.0/0 > /dev/null 2>&1
neutron security-group-rule-create default --protocol tcp --port-range-min 22 --port-range-max 22 --remote-ip-prefix 0.0.0.0/0 > /dev/null 2>&1 || true
#for rdp
neutron security-group-rule-create default --protocol tcp --port-range-min 3389 --port-range-max 3389 --remote-ip-prefix 0.0.0.0/0 > /dev/null 2>&1 || true

echo "Uploading default SSH key"

#Upload a default SSH key
nova keypair-list | grep default  > /dev/null 2>&1 || nova  keypair-add --pub-key ~/.ssh/id_rsa.pub default > /dev/null 2>&1

echo "Modifying the flavors to be better sized for the Orange Box"

#Modify the flavours to fit better on the OB
#nova flavor-create FLAVOR_NAME FLAVOR_ID RAM_IN_MB ROOT_DISK_IN_GB NUMBER_OF_VCPUS
nova flavor-delete m1.tiny > /dev/null 2>&1
nova flavor-delete m1.small > /dev/null 2>&1
nova flavor-delete m1.medium > /dev/null 2>&1
nova flavor-delete m1.large > /dev/null 2>&1
nova flavor-delete m1.xlarge > /dev/null 2>&1
nova flavor-create --is-public true m1.tiny auto 512 5 1 > /dev/null 2>&1
nova flavor-create --is-public true m1.small auto 1024 10 1 > /dev/null 2>&1
nova flavor-create --is-public true m1.medium auto 2048 10 2 > /dev/null 2>&1
nova flavor-create --is-public true m1.large auto 3072 10 2 > /dev/null 2>&1
nova flavor-create --is-public true m1.xlarge auto 4096 20 2 > /dev/null 2>&1

echo "modifying default quotas for admin user"

#Modify quotas for the tenant to allow large deployments
nova quota-update --instances 100 $TENANT_ID
nova quota-update --cores 200 $TENANT_ID
nova quota-update --ram 204800 $TENANT_ID
#nova quota-update --security-groups 200 $TENANT_ID
neutron quota-update --tenant-id $TENANT_ID --security-group 200
echo "Uploading images to glance"

#Upload images to glance
glance image-show "Precise x86_64" > /dev/null 2>&1 || glance add name="Precise x86_64" is_public=true container_format=ovf disk_format=qcow2 <  /srv/data/precise-server-cloudimg-amd64-disk1.img 
glance image-show "Trusty x86_64" > /dev/null 2>&1 || glance add name="Trusty x86_64" is_public=true container_format=ovf disk_format=qcow2 <  /srv/data/trusty-server-cloudimg-amd64-disk1.img
glance image-show "CentOS 6.4" > /dev/null 2>&1 || glance add name="CentOS 6.4" is_public=true container_format=bare disk_format=qcow2 < /srv/data/centos6.4-x86_64-gold-master.img
glance image-show "Cirros 0.3" > /dev/null 2>&1 || glance add name="Cirros 0.3" is_public=true container_format=bare disk_format=qcow2 < /srv/data/cirros-0.3.2-x86_64-disk.img
glance image-show "Windows Server 2012" > /dev/null 2>&1 || glance add name="Windows Server 2012" is_public=true container_format=bare disk_format=qcow2 < /srv/data/windows_server_2012_r2_standard_eval_kvm_20131117.qcow2 &

exit
