#!/bin/bash
#
set -e

echo "This command is run to launch the first instance on a new Orange box Project Calico Openstack deployment"

source ~/nova.rc

#First check if v6server already exists
nova list | grep v6server && echo "v6server already exists, terminate instance before running this script again." && exit

#Create a floating IP for the instance - floating IPs not used
#FLOAT_IP="$(nova floating-ip-create | grep ext_net | awk '{ print $2}')"

#Launch an instance
EXT_NET_UUID="$(nova net-list | grep ext_net | awk '{ print $2 }')"
PRIV_NET_UUID="$(nova net-list | grep private | awk '{ print $2 }')"
IMAGE_UUID="$(nova image-list | grep Calico | awk '{ print $2 }')"
#IMAGE_UUID="$(nova image-list | grep "Trusty x86_64" | awk '{ print $2 }')"
FLAVOR_UUID="$(nova flavor-list | grep m1.medium | awk '{ print $2 }')"
nova boot --flavor $FLAVOR_UUID --key_name default --image $IMAGE_UUID --nic net-id=$EXT_NET_UUID --security_group default v6server
while nova list --status BUILD | grep v6server; do
        sleep 10
done

sleep 10
#get IP
FLOAT_IP=$(nova list | grep v6server | sed -e 's/^.*=//' -e 's/ |//' -e 's/, .*:.*//' -e 's/^.*:.*, //')
#SSH into the instance and install Juju stable PPA
ssh -o StrictHostKeyChecking=no ubuntu@$FLOAT_IP "sudo add-apt-repository -y ppa:juju/stable && sudo apt-get update"

#SSH into the instance and install Juju
ssh -o StrictHostKeyChecking=no ubuntu@$FLOAT_IP "sudo apt-get -y install juju-core juju-quickstart juju-deployer"

#Set up the Juju default environment
ssh -o StrictHostKeyChecking=no ubuntu@$FLOAT_IP "juju init"

#copy over SSH keys
scp -o StrictHostKeyChecking=no ~/.ssh/id_rsa* ubuntu@$FLOAT_IP:~/.ssh/

#Output a juju env file that works on this cloud
RADOSGW_IP="$(juju pprint | grep ceph-radosgw | cut -f3 -d' ')"
ssh -o StrictHostKeyChecking=no ubuntu@$FLOAT_IP "echo 'default: openstack
environments:
    openstack:
        type: openstack
        network: ext_net
        auth-url: $OS_AUTH_URL
        tenant-name: $OS_TENANT_NAME
        region: $OS_REGION_NAME
        auth-mode: userpass
        username: $OS_USERNAME
        password: $OS_PASSWORD
        admin-secret: $OS_PASSWORD
        default-series: trusty
        image-metadata-url: http://$RADOSGW_IP/swift/v1/juju-bucket/images
        http-proxy: http://10.14.4.1:8000
        https-proxy: http://10.14.4.1:8000
        ftp-proxy: http://10.14.4.1:8000
        no-proxy: localhost,10.14.4.1,169.254.169.254
        apt-http-proxy: http://10.14.4.1:8000
        apt-https-proxy: http://10.14.4.1:8000
        apt-ftp-proxy: http://10.14.4.1:8000
' > ~/.juju/environments.yaml"
#Need to set metadata-url in above block

#Create juju metadata
ssh -o StrictHostKeyChecking=no ubuntu@$FLOAT_IP "juju-metadata generate-image -a amd64 -u $OS_AUTH_URL -i $IMAGE_UUID -r $OS_REGION_NAME -s trusty"

IMAGE_UUID="$(nova image-list | grep Precise | awk '{ print $2 }')"
ssh -o StrictHostKeyChecking=no ubuntu@$FLOAT_IP "juju-metadata generate-image -a amd64 -u $OS_AUTH_URL -i $IMAGE_UUID -r $OS_REGION_NAME -s precise"

#Upload metadata to cloud storage!
rm -rf images
scp -r -o StrictHostKeyChecking=no ubuntu@$FLOAT_IP:images ./
swift post juju-bucket -r .r:*
swift upload juju-bucket images

#Bootstrap Juju
ssh -o StrictHostKeyChecking=no ubuntu@$FLOAT_IP "juju bootstrap --show-log"

#Deploy juju-gui
ssh -o StrictHostKeyChecking=no ubuntu@$FLOAT_IP "juju deploy --to 0 juju-gui && juju expose juju-gui"

#Install the Orange-box-examples package
ssh -o StrictHostKeyChecking=no ubuntu@$FLOAT_IP "sudo apt-get install -y bzr && bzr branch lp:orange-box-examples Examples"

#Install the SA keys
ssh -o StrictHostKeyChecking=no ubuntu@$FLOAT_IP "~/Examples/bin/orange-box-import-SA-keys;cat ~/.ssh/authorized_keys.old >> ~/.ssh/authorized_keys"

#Print the address of Juju-gui for deployments on Openstack
GUI_HOST=$(ssh -o StrictHostKeyChecking=no ubuntu@$FLOAT_IP "juju stat juju-gui | grep public-address | sed -e 's/.*public-address: //'")
echo "Now connect to the Juju-GUI at: http://$GUI_HOST/ to continue deployments on Openstack."
echo "Pass: $OS_PASSWORD"

echo "OR Log in to openstack Jumpserver to deploy from command line"
echo "ssh ubuntu@$FLOAT_IP"
exit

