#!/bin/bash -e


mydomain=$1
cat > bundle-$mydomain.yaml <<EOF
phone-network: 
  services: 
    "clearwater-bono": 
      charm: "cs:~thomnico/precise/clearwater-bono"
      num_units: 1
      options: 
        zone: $mydomain
      constraints: arch=amd64 mem=2G
      expose: true
      annotations: 
        "gui-x": "400"
        "gui-y": "900"
    "clearwater-ellis": 
      charm: "cs:~thomnico/precise/clearwater-ellis"
      num_units: 1
      options: 
        base_number: "1234567000"
        number_count: 1000
        signup_key: signup
        zone: $mydomain
      constraints: arch=amd64 mem=2G
      expose: true
      annotations: 
        "gui-x": "400"
        "gui-y": "0"
      to: 
        - lxc:clearwater-bono=0
    clearwater-homer: 
      charm: "cs:~thomnico/precise/clearwater-homer"
      num_units: 1
      options: 
        zone: $mydomain
      constraints: arch=amd64 mem=2G
      expose: true
      annotations: 
        "gui-x": "600"
        "gui-y": "300"
    "clearwater-homestead": 
      charm: "cs:~thomnico/precise/clearwater-homestead"
      num_units: 1
      options: 
        zone: $mydomain
      constraints: arch=amd64 mem=2G
      expose: true
      annotations: 
        "gui-x": "200"
        "gui-y": "300"
      to: lxc:clearwater-homer=0
    clearwater-sprout: 
      charm: "cs:~thomnico/precise/clearwater-sprout"
      num_units: 1
      options: 
        zone: $mydomain
      constraints: arch=amd64 mem=2G
      expose: true
      annotations: 
        "gui-x": "400"
        "gui-y": "600"
    dns: 
      charm: "cs:~thomnico/precise/dns"
      num_units: 1
      constraints: arch=amd64 mem=2G
      expose: true
      options: 
        domain: $mydomain
      annotations: 
        "gui-x": "1000"
        "gui-y": "450"
      to: lxc:clearwater-bono=0
    telscale-load-balancer: 
      charm: "cs:~thomnico/trusty/telscale-load-balancer"
      num_units: 1
      expose: true
      constraints: arch=amd64 mem=2G
      annotations: 
        "gui-x": "-500.2210693359375"
        "gui-y": "412.7301025390625"
    mysql: 
      charm: "cs:trusty/mysql-5"
      num_units: 1
      constraints: arch=amd64 mem=2G
      annotations: 
        "gui-x": "-500.8215242215981"
        "gui-y": "698.5485784445332"
      to: lxc:telscale-load-balancer=0
    sipml5:
      charm: "cs:~thomnico/trusty/sipml5"
      num_units: 1
      expose: true
      annotations: 
        "gui-x": "1383.4697265625"
        "gui-y": "423.10858154296875"
      to: lxc:clearwater-bono=0
    telscale-restcomm: 
      charm: "cs:~thomnico/trusty/telscale-restcomm"
      num_units: 1
      constraints: arch=amd64 mem=2G
      expose: true
      annotations: 
        "gui-x": "-500.625244140625"
        "gui-y": "547.9537963867188"
      to: lxc:telscale-load-balancer=0
  relations: 
    - - "clearwater-bono:scscf"
      - "clearwater-sprout:pcscf"
    - - "clearwater-homestead:homestead-cscf"
      - "clearwater-sprout:homestead-hss"
    - - "clearwater-homer:xdms-user"
      - "clearwater-sprout:xdms"
    - - "clearwater-ellis:homestead-prov"
      - "clearwater-homestead:homestead-prov-user"
    - - "clearwater-ellis:xdms"
      - "clearwater-homer:xdms-user"
    - - "clearwater-ellis:programmable-multiple"
      - "dns:programmable-multiple"
    - - "clearwater-homer:programmable-multiple"
      - "dns:programmable-multiple"
    - - "clearwater-bono:programmable-multiple"
      - "dns:programmable-multiple"
    - - "clearwater-sprout:programmable-multiple"
      - "dns:programmable-multiple"
    - - "clearwater-homestead:programmable-multiple"
      - "dns:programmable-multiple"
    - - "sipml5:dns-client"
      - "dns:dns-client"
    - - "mysql:db"
      - "telscale-restcomm:database"
    - - "telscale-restcomm:load-balancer"
      - "telscale-load-balancer:load-balancer"
    - - "telscale-load-balancer:clearwater-ellis"
      - "clearwater-ellis:as-catalog"
    - - "telscale-restcomm:cscf"
      - "clearwater-sprout:as"
  series: trusty
EOF

echo "You can know drag/drop bundle-$mydomain.yaml"
echo "Or juju-quickstart bundle-$mydomain.yaml"
echo " "
