#!/bin/bash
#
#    orangebox-switch-custom-script.sh
#    Copyright (C) 2015 Canonical Ltd.
#
#    Authors: Gary Mackenzie <gary.mackenzie@canonical.com?
#    Modified by: launchpad.net/~mahmoh
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, version 3 of the License.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#    Version 1.0

# set -x 

# Figure out which two digit OB we're on
OB=$(hostname | sed -e "s/[^0-9]//g")
BYTE1=$(echo $OB | cut -c 1)
BYTE2=$(echo $OB | cut -c 2)

if [ $BYTE1 -eq 0 ] 
then
	OB=$BYTE2
fi

if expr $OB % 4 ; then
   echo "The OB number must be a multiple of four, please fix the hostname (i.e. "OrangeBox12" )"
   exit
fi

# If someone supplied an argument assume they know what they're doing
if ! [ "$1" == "" ] ; then
    OB=$1
fi

PLUS1=`expr $OB + 1`
PLUS2=`expr $OB + 2`
PLUS3=`expr $OB + 3`

if ( ip addr show br0 ) ; then
    INT=br0
elif ( ip addr show br1 ) ; then
    INT=br0
else
    INT=eth1
fi

echo Using interface $INT ...

echo Adding IP 172.27.[orangebox].1/23
sudo ip addr add 172.27.$OB.1/23 dev $INT
echo Adding IP 192.168.88.2/24
sudo ip addr add 192.168.88.2/24 dev $INT
echo Adding IP 172.27.0.1/23
sudo ip addr add 172.27.0.1/23 dev $INT
echo Completed adding IPs

echo Waiting 10 seconds for interfaces to come up ...
sleep 10
sudo chown ubuntu:ubuntu /home/ubuntu/.ssh/known_hosts
ssh-keygen -f "/home/ubuntu/.ssh/known_hosts" -R 192.168.88.1
echo Wiped ssh key for 192.168.88.1

echo Uploading baseline configuration
scp -o "StrictHostKeyChecking no" orangebox-baseline.backup admin@192.168.88.1:
echo Complete

echo Loading baseline config and rebooting
ssh -o "StrictHostKeyChecking no" admin@192.168.88.1 /beep
ssh -o "StrictHostKeyChecking no" admin@192.168.88.1 /beep
ssh -o "StrictHostKeyChecking no" admin@192.168.88.1 /beep
ssh -o "StrictHostKeyChecking no" admin@192.168.88.1 /system backup load name=orangebox-baseline.backup password=\n

echo Waiting 30 seconds for switch to reboot

sleep 30

until ping -c 1 172.27.1.254; do
    echo The host is down, waiting until it is back up ...
    sleep 5
done

ssh-keygen -f "/home/ubuntu/.ssh/known_hosts" -R 172.27.1.254
echo Wiped ssh key for 172.27.1.254

ssh-keygen -f "/home/ubuntu/.ssh/known_hosts" -R 172.27.$PLUS1.254
echo Wiped ssh key for 172.27.5.254

echo Resetting MAC addresses from baseline configuration
echo Resetting eth1
ssh -o "StrictHostKeyChecking no" -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /interface ethernet reset-mac-address 0
echo Resetting eth2
ssh -o "StrictHostKeyChecking no" -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /interface ethernet reset-mac-address 1
echo Resetting eth3
ssh -o "StrictHostKeyChecking no" -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /interface ethernet reset-mac-address 2
echo Resetting eth4
ssh -o "StrictHostKeyChecking no" -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /interface ethernet reset-mac-address 3
echo Resetting eth5
ssh -o "StrictHostKeyChecking no" -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /interface ethernet reset-mac-address 4
echo Resetting eth6
ssh -o "StrictHostKeyChecking no" -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /interface ethernet reset-mac-address 5
echo Resetting eth7
ssh -o "StrictHostKeyChecking no" -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /interface ethernet reset-mac-address 6 
echo Resetting eth8
ssh -o "StrictHostKeyChecking no" -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /interface ethernet reset-mac-address 7
echo Resetting eth9
ssh -o "StrictHostKeyChecking no" -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /interface ethernet reset-mac-address 8
echo Resetting eth10
ssh -o "StrictHostKeyChecking no" -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /interface ethernet reset-mac-address 9
echo Resetting eth11
ssh -o "StrictHostKeyChecking no" -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /interface ethernet reset-mac-address 10
echo Resetting eth12
ssh -o "StrictHostKeyChecking no" -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /interface ethernet reset-mac-address 11
echo Resetting eth13
ssh -o "StrictHostKeyChecking no" -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /interface ethernet reset-mac-address 12
echo Resetting eth14
ssh -o "StrictHostKeyChecking no" -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /interface ethernet reset-mac-address 13
echo Resetting eth15
ssh -o "StrictHostKeyChecking no" -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /interface ethernet reset-mac-address 14
echo Resetting eth16
ssh -o "StrictHostKeyChecking no" -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /interface ethernet reset-mac-address 15
echo Resetting eth17
ssh -o "StrictHostKeyChecking no" -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /interface ethernet reset-mac-address 16
echo Resetting eth18
ssh -o "StrictHostKeyChecking no" -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /interface ethernet reset-mac-address 17
echo Resetting eth19
ssh -o "StrictHostKeyChecking no" -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /interface ethernet reset-mac-address 18
echo Resetting eth20
ssh -o "StrictHostKeyChecking no" -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /interface ethernet reset-mac-address 19
echo Resetting eth21
ssh -o "StrictHostKeyChecking no" -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /interface ethernet reset-mac-address 20
echo Resetting eth22
ssh -o "StrictHostKeyChecking no" -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /interface ethernet reset-mac-address 21
echo Resetting eth23
ssh -o "StrictHostKeyChecking no" -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /interface ethernet reset-mac-address 22
echo Resetting eth24
ssh -o "StrictHostKeyChecking no" -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /interface ethernet reset-mac-address 23
echo Resetting eth25
ssh -o "StrictHostKeyChecking no" -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /interface ethernet reset-mac-address 24
echo Completed

ssh -o "StrictHostKeyChecking no" admin@172.27.1.254 /beep frequency=250 length 0.5

echo Uploading bridge-rebuild script
scp -o "StrictHostKeyChecking no" bridge-rebuild.rsc ubuntu@172.27.1.254:
echo Complete

echo Rebuilding bridge interfaces to flush MAC addresses
ssh -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /import bridge-rebuild.rsc
echo Complete

echo Setting switch hostname
ssh -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /system identity set name=OrangeBox$OB
echo Complete

echo Setting Wireless SSID
ssh -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /interface wireless set ssid=OrangeBox$OB numbers=0
echo Complete

ssh -o "StrictHostKeyChecking no" admin@172.27.1.254 /beep frequency=500 length 0.5

echo Setting bridge-vlan1 IP address
ssh -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /ip address add address=172.27.$PLUS1.254/23 interface=bridge-vlan1 network=172.27.$OB.0
echo Complete

echo Setting bridge-vlan2 IP address
ssh -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /ip address add address=172.27.$PLUS3.254/23 interface=bridge-vlan2 network=172.27.$PLUS2.0
echo Complete

echo Setting bridge-vlan3 IP address
ssh -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /ip address add address=172.27.252.$OB/22 interface=bridge-vlan3 network=172.27.252.0
echo Complete

ssh -o "StrictHostKeyChecking no" admin@172.27.1.254 /beep frequency=750 length 0.5


echo Remove baseline DHCP config
ssh -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /ip dhcp-server network remove numbers=0
echo Complete

echo Setting DHCP lease configuration
ssh -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /ip dhcp-server network add address=172.27.252.0/22 dns-server=172.27.252.$OB gateway=172.27.252.$OB netmask=22
echo Complete

ssh -o "StrictHostKeyChecking no" admin@172.27.1.254 /beep frequency=1000 length 0.5


echo Set port forwarding for tcp/2222 to node0
ssh -o "StrictHostKeyChecking no" ubuntu@172.27.1.254 /ip firewall nat add action=dst-nat chain=dstnat dst-port=2222 protocol=tcp to-addresses=172.27.$OB.1 to-ports=22
echo Complete

ssh -o "StrictHostKeyChecking no" admin@172.27.1.254 /beep frequency=1250 length 1

echo Remove baseline network address 1 of 3
ssh -o "StrictHostKeyChecking no" ubuntu@172.27.$PLUS1.254 /ip address remove numbers=2

echo Remove baseline network address 2 of 3
ssh -o "StrictHostKeyChecking no" ubuntu@172.27.$PLUS1.254 /ip address remove numbers=1

echo Remove baseline network address 3 of 3
ssh -o "StrictHostKeyChecking no" ubuntu@172.27.$PLUS1.254 /ip address remove numbers=0
echo Complete

#REMOVING ALIAS IPs
echo Remove eth1 IP alias 1 of 2 
sudo ifconfig eth1:1 down
echo Remove eth1 IP alias 2 of 2 
sudo ifconfig eth1:2 down
echo Complete


echo All switch configuration complete, saving recovery config and restore file ...
ssh -o "StrictHostKeyChecking no" ubuntu@172.27.$PLUS1.254 /export verbose file=orangebox-$OB-recovery.rsc
ssh -o "StrictHostKeyChecking no" ubuntu@172.27.$PLUS1.254 /system backup save name=OrangeBox$OB-v4n-initial.backup password=\n
echo Complete
echo Copying recovery configuration and restore file to node0
scp -o "StrictHostKeyChecking no" ubuntu@172.27.$PLUS1.254:orangebox-$OB-switch-recovery.rsc ~/
scp -o "StrictHostKeyChecking no" ubuntu@172.27.$PLUS1.254:orangebox-$OB-switch-v4n-initial.backup ~/
echo Complete
ssh -o "StrictHostKeyChecking no" ubuntu@172.27.$PLUS1.254 /beep
ssh -o "StrictHostKeyChecking no" ubuntu@172.27.$PLUS1.254 /beep
ssh -o "StrictHostKeyChecking no" ubuntu@172.27.$PLUS1.254 /beep
ssh -o "StrictHostKeyChecking no" ubuntu@172.27.$PLUS1.254 /beep
echo Rebooting ...
ssh -o "StrictHostKeyChecking no" ubuntu@172.27.$PLUS1.254 /system reboot
